@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2011 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: airtools.h,v 1.5 2011/08/15 20:45:51 cvs Exp $
+//      $Id: airtools.h,v 1.6 2011/08/16 22:26:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,8 @@
 #ifndef AIRTOOLS_H
 #define AIRTOOLS_H
 
+#include <stdint.h>
+
 #include <qtimer.h>
 #include <qsocketnotifier.h>
 
@@ -56,7 +58,7 @@ class AirTools : public Delay
 {
  Q_OBJECT
  public:
-  AirTools(Profile *p,int n,QObject *parent,const char *name=0);
+  AirTools(Profile *p,int n,bool debug,QObject *parent,const char *name=0);
   ~AirTools();
   Cunctator::DelayType type();
   QString description();
@@ -85,6 +87,11 @@ class AirTools : public Delay
   int airtools_entering_debounce;
   int airtools_exiting_debounce;
   char airtools_status_mask;
+  bool airtools_stats_requested;
+  int airtools_host_revision_major;
+  int airtools_host_revision_minor;
+  int airtools_dsp_revision_major;
+  int airtools_dsp_revision_minor;
 };
 
 
