@@ -36,9 +36,9 @@ class CuncConfig : public QObject
 {
   Q_OBJECT;
  public:
-  CuncConfig(QObject *parent=0,const char *name=0);
+  CuncConfig(bool debug,QObject *parent=0,const char *name=0);
+  CuncConfig(QString filename,bool debug);
   ~CuncConfig();
-  CuncConfig(QString filename);
   QString filename() const;
   void setFilename(QString filename);
   unsigned tcpPort() const;
@@ -72,6 +72,7 @@ class CuncConfig : public QObject
   std::vector<RmlEngine *> conf_rml_engines;
   std::vector<UdpQueue *> conf_udp_queues;
   QString conf_filename;
+  bool conf_debug;
 };
 
 
