@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2011 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cuncd.cpp,v 1.11 2011/08/05 20:59:52 cvs Exp $
+//      $Id: cuncd.cpp,v 1.12 2011/08/16 22:26:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -101,7 +101,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   //
   // Load Local Configs
   //
-  cuncd_config=new CuncConfig(CUNC_CONF_FILE);
+  cuncd_config=new CuncConfig(CUNC_CONF_FILE,debug);
   cuncd_config->load();
   //cuncd_config->dumpConfig(stdout);
 
