@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2011 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: dummy.h,v 1.4 2011/02/24 16:43:54 cvs Exp $
+//      $Id: dummy.h,v 1.5 2011/08/16 22:26:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,7 +34,7 @@ class Dummy : public Delay
 {
  Q_OBJECT
  public:
-  Dummy(Profile *p,int n,QObject *parent,const char *name=0);
+  Dummy(Profile *p,int n,bool debug,QObject *parent,const char *name=0);
   ~Dummy();
   Cunctator::DelayType type();
   QString description();
