@@ -49,7 +49,8 @@
 class Cunctator
 {
  public:
-  enum DelayType {TypeUnknown=0,TypeDummy=1,TypeAirTools=2,TypeBd600=3};
+  enum DelayType {TypeUnknown=0,TypeDummy=1,TypeAirTools=2,TypeBd600=3,
+		  TypeJackDelay=4};
   enum DelayState {StateUnknown=0,StateBypassed=1,StateEntered=2,
 		   StateEntering=3,StateExited=4,StateExiting=5};
 };
